@@ -1,8 +1,8 @@
 w <- gwindow("gtext example", visible=FALSE)
 
 ## constrouctor -- font.attr sets for buffer
-widget <- gtext("test text", cont = w, font.attr=c(size=24L, color="blue"))
-add(widget, "new text", font.attr=c(family="monospace"))
+widget <- gtext("test text", cont = w, font.attr=list(size=24L, color="blue"))
+insert(widget, "new text", font.attr=c(family="monospace"))
 
                 
 # svalue
@@ -13,6 +13,6 @@ svalue(widget) <- "new label"
 
 # font<-
 # sets for buffer if no selection
-font(widget) <- c(family="monospace", "weight"="bold", "color"="red", size="xx-large")
+#font(widget) <- list(family="monospace", "weight"="bold", "color"="red", size="xx-large")
 
 visible(w) <- TRUE
